pub fn find(name: &str) -> Option<Variable>Expand description
Returns a copy of the value of the shell variable referenced by name.
If the shell variable does not exist, it returns None.
Use find_as_string if you want to skip arrays.
pub fn find(name: &str) -> Option<Variable>Returns a copy of the value of the shell variable referenced by name.
If the shell variable does not exist, it returns None.
Use find_as_string if you want to skip arrays.