Struct bash_builtins::variables::RawVariable [−][src]
pub struct RawVariable(_);Expand description
Raw reference to a shell variable.
Every method is unsafe because this type contains a raw pointer to an address owned by bash.
Whenever possible, use find or find_as_string functions to get the
value of a shell variable.
Implementations
Returns true if the shell variable contains an indexed array.
Safety
This method is unsafe because it does not check that the address of the shell variable is still valid.
Returns true if the shell variable contains an associative array.
Safety
This method is unsafe because it does not check that the address of the shell variable is still valid.
Extracts the contents of the shell variable, and returns a copy of the it.
Safety
This method is unsafe because it does not check that the address of the shell variable is still valid.
Returns a reference to the string contained in the shell variable. If
the shell variable contains an array, returns None.
Safety
This method is unsafe for two reasons:
- It does not check that the address of the shell variable is still valid.
- The
CStrreference is wrapping a pointer managed by bash, so its lifetime is not guaranteed.
Returns an iterator over items of the indexed array contained in the variable.
Safety
This method is unsafe for two reasons:
- It does not check that the address of the shell variable is still valid.
- It does not check that the shell variable contains an indexed array.
Returns an iterator over items of the associative array contained in the shell variable.
Safety
This method is unsafe for two reasons:
- It does not check that the address of the shell variable is still valid.
- It does not check that the shell variable contains an associative array.